==> camel-k-model-v1-5.3.0-sources.jar: annotations/io/fabric8/camelk/v1/IntegrationPlatformListFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface IntegrationPlatformListFluent<A extends IntegrationPlatformListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,IntegrationPlatform item);
    public A setToItems(int index,IntegrationPlatform item);
    public A addToItems(IntegrationPlatform... items);
    public A addAllToItems(Collection<IntegrationPlatform> items);
    public A removeFromItems(IntegrationPlatform... items);
    public A removeAllFromItems(Collection<IntegrationPlatform> items);
    public A removeMatchingFromItems(Predicate<IntegrationPlatformBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<IntegrationPlatform> getItems();
    public List<IntegrationPlatform> buildItems();
    public IntegrationPlatform buildItem(int index);
    public IntegrationPlatform buildFirstItem();
    public IntegrationPlatform buildLastItem();
    public IntegrationPlatform buildMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
    public A withItems(List<IntegrationPlatform> items);
    public A withItems(IntegrationPlatform... items);
    public Boolean hasItems();
    public IntegrationPlatformListFluent.ItemsNested<A> addNewItem();
    public IntegrationPlatformListFluent.ItemsNested<A> addNewItemLike(IntegrationPlatform item);
    public IntegrationPlatformListFluent.ItemsNested<A> setNewItemLike(int index,IntegrationPlatform item);
    public IntegrationPlatformListFluent.ItemsNested<A> editItem(int index);
    public IntegrationPlatformListFluent.ItemsNested<A> editFirstItem();
    public IntegrationPlatformListFluent.ItemsNested<A> editLastItem();
    public IntegrationPlatformListFluent.ItemsNested<A> editMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IntegrationPlatformFluent<IntegrationPlatformListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> camel-k-model-v1-5.3.1-sources.jar: annotations/io/fabric8/camelk/v1/IntegrationPlatformListFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface IntegrationPlatformListFluent<A extends IntegrationPlatformListFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,IntegrationPlatform item);
    public A setToItems(int index,IntegrationPlatform item);
    public A addToItems(IntegrationPlatform... items);
    public A addAllToItems(Collection<IntegrationPlatform> items);
    public A removeFromItems(IntegrationPlatform... items);
    public A removeAllFromItems(Collection<IntegrationPlatform> items);
    public A removeMatchingFromItems(Predicate<IntegrationPlatformBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<IntegrationPlatform> getItems();
    public List<IntegrationPlatform> buildItems();
    public IntegrationPlatform buildItem(int index);
    public IntegrationPlatform buildFirstItem();
    public IntegrationPlatform buildLastItem();
    public IntegrationPlatform buildMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
    public A withItems(List<IntegrationPlatform> items);
    public A withItems(IntegrationPlatform... items);
    public Boolean hasItems();
    public io.fabric8.camelk.v1.IntegrationPlatformListFluent.ItemsNested<A> addNewItem();
    public io.fabric8.camelk.v1.IntegrationPlatformListFluent.ItemsNested<A> addNewItemLike(IntegrationPlatform item);
    public io.fabric8.camelk.v1.IntegrationPlatformListFluent.ItemsNested<A> setNewItemLike(int index,IntegrationPlatform item);
    public io.fabric8.camelk.v1.IntegrationPlatformListFluent.ItemsNested<A> editItem(int index);
    public io.fabric8.camelk.v1.IntegrationPlatformListFluent.ItemsNested<A> editFirstItem();
    public io.fabric8.camelk.v1.IntegrationPlatformListFluent.ItemsNested<A> editLastItem();
    public io.fabric8.camelk.v1.IntegrationPlatformListFluent.ItemsNested<A> editMatchingItem(Predicate<IntegrationPlatformBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IntegrationPlatformFluent<io.fabric8.camelk.v1.IntegrationPlatformListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
